@@ -929,25 +929,6 @@ ACTUALIZE_TASK_SCHEMA = '''{
                     "minimum": -12,
                     "type": "integer"
                 },
-                "strategy": {
-                    "additionalProperties": false,
-                    "nullable": false,
-                    "properties": {
-                        "create_new_trips": {
-                            "default": false,
-                            "type": "boolean"
-                        },
-                        "plan_new_orders": {
-                            "default": true,
-                            "type": "boolean"
-                        },
-                        "reorder": {
-                            "default": false,
-                            "type": "boolean"
-                        }
-                    },
-                    "type": "object"
-                },
                 "toll_roads": {
                     "default": true,
                     "type": "boolean"
